@@ -315,8 +315,7 @@ class SagemakerFeatureStore:
             record = self.runtime.get_record(
                 FeatureGroupName=feature_group_name,
                 RecordIdentifierValueAsString=record_identifier,
-            )
-            print(record)
+            )["Record"]
 
         return self._reformat_to_dict(record)
 
@@ -704,12 +703,18 @@ if __name__ == "__main__":
         aws_access_key_id, aws_secret_access_key, "ap-southeast-1", role
     )
 
-    feature_group_name = "kumuniverse-fg-test"
+    # features_list = ["streamer_id", "cover_photo_embedding"]
+    # raw_data = feature_store.get_online_features(
+    #     "streamers-cpce-fg-11-06-54-38", "cpce:6WEL21LZxiyBQ78q"
+    # )
+    # print(json.dumps(raw_data, indent=2))
+
+    # feature_group_name = "kumuniverse-fg-test"
 
     # Feature Group Creation Example
     # Prepare Pandas dataset for ingestion
-    record_identifier_feature_name = "streamer_id"
-    event_time_feature_name = "EventTime"
+    # record_identifier_feature_name = "streamer_id"
+    # event_time_feature_name = "EventTime"
 
     # df = pd.read_csv("streamers_cpce.csv")
     # df.drop(columns=["expiry", "updated_at"], inplace=True)
@@ -751,10 +756,10 @@ if __name__ == "__main__":
     # raw_data = feature_store.get_online_features(
     #     feature_group_name, "cpce:6WEL21LZxiyBQ78q"
     # )
-    raw_data = feature_store.get_online_features(
-        "v3-cross-test-14", "112VRJCR76KZKVMG#%crpZK4317791xTQy"
-    )
-    print(raw_data)
+    # raw_data = feature_store.get_online_features(
+    #     "v3-cross-test-14", "112VRJCR76KZKVMG#%crpZK4317791xTQy"
+    # )
+    # print(raw_data)
     # t1 = time.time()
     # total = t1 - t0
     # print("Single Query Time Execution:", round(total * 1000))
